@@ -5,7 +5,7 @@ mod_2_medias_dependentes_Ui <- function(id){
 
   tagList(
 
-    uiOutput(ns("aba")) %>%
+    uiOutput(ns("aba")) |>
       shinycssloaders::withSpinner(type = 5)
 
   )# Fecha tagList
@@ -16,7 +16,8 @@ mod_2_medias_dependentes_Ui <- function(id){
 
 mod_2_medias_dependentes_server <- function(id, tipo = "tamanho_amostral", txt_ajuda, h1,
                                             translation_pss, linguagem, .rodape, try_n, validate_n, ajuda_cenarios_multiplos_valores, validate_n_inf, n_perdas, print_r_code, text_input_to_vector, check_text_input_to_vector,
-                                            warning_prop, warning_numero_positivo, warning_inteiro, warning_perdas, warning_numero){
+                                            warning_prop, warning_numero_positivo, warning_inteiro, warning_perdas, warning_numero,
+                                            lista_de_funcoes_server){
   shiny::moduleServer(
     id,
     function(input, output, session){
@@ -44,7 +45,11 @@ mod_2_medias_dependentes_server <- function(id, tipo = "tamanho_amostral", txt_a
           sidebarPanel(
 
 
-            wellPanel(HTML('<b><a href="https://youtu.be/mp8qbyUSqV0" target="_blank">Vídeo: PSS Health para comparar dua médias</a></b><br>')),
+            wellPanel(HTML(
+              '<b><a href="https://youtu.be/mp8qbyUSqV0" target="_blank">',
+              translation_pss("Vídeo: PSS Health para comparar dua médias", linguagem()),
+              '</a></b><br>'
+            )),
 
             if (tipo %in% c("tamanho_amostral", "poder")) {
               wellPanel(
@@ -71,7 +76,7 @@ mod_2_medias_dependentes_server <- function(id, tipo = "tamanho_amostral", txt_a
                             min = -Inf,
                             max = Inf,
                             step = .5
-              ) %>% .help_buttom(body = txt_ajuda()$txt_diferenca_clinica, title = translation_pss("Diferença mínima a ser detectada", linguagem()))
+              ) |> .help_buttom(linguagem = linguagem(), body = txt_ajuda()$txt_diferenca_clinica, title = translation_pss("Diferença mínima a ser detectada", linguagem()))
             },
 
             numericInput( ns("sigma"),
@@ -80,7 +85,7 @@ mod_2_medias_dependentes_server <- function(id, tipo = "tamanho_amostral", txt_a
                           min = 0,
                           max = Inf,
                           step = 1
-            ) %>% .help_buttom(body = txt_ajuda()$txt_dp, title = translation_pss("Desvio padrão", linguagem())),
+            ) |> .help_buttom(linguagem = linguagem(), body = txt_ajuda()$txt_dp, title = translation_pss("Desvio padrão", linguagem())),
 
             actionLink(ns("show_desvio_diferenca"), translation_pss("Calcular o desvio padrão da diferença", linguagem())),
             br(), br(),
@@ -103,7 +108,7 @@ mod_2_medias_dependentes_server <- function(id, tipo = "tamanho_amostral", txt_a
                             min = 0,
                             max = Inf,
                             step = 0.1
-              ) %>% .help_buttom(body = txt_ajuda()$txt_precisao, title = translation_pss("Margem de erro/ semi-amplitude", linguagem()))
+              ) |> .help_buttom(linguagem = linguagem(), body = txt_ajuda()$txt_precisao, title = translation_pss("Margem de erro/ semi-amplitude", linguagem()))
 
             } else if (tipo == "tamanho_amostral") {
               numericInput( ns("poder"),
@@ -112,7 +117,7 @@ mod_2_medias_dependentes_server <- function(id, tipo = "tamanho_amostral", txt_a
                             min = 0,
                             max = 100,
                             step = 1
-              ) %>% .help_buttom(body = txt_ajuda()$txt_power, title = translation_pss("Poder (%)", linguagem()))
+              ) |> .help_buttom(linguagem = linguagem(), body = txt_ajuda()$txt_power, title = translation_pss("Poder (%)", linguagem()))
             },
 
 
@@ -124,13 +129,13 @@ mod_2_medias_dependentes_server <- function(id, tipo = "tamanho_amostral", txt_a
                               min = 0,
                               max = 100,
                               step = 1
-                ) %>% .help_buttom(body = txt_ajuda()$txt_significancia, title = translation_pss("Nível de significância (%)", linguagem())),
+                ) |> .help_buttom(linguagem = linguagem(), body = txt_ajuda()$txt_significancia, title = translation_pss("Nível de significância (%)", linguagem())),
 
                 selectInput(ns('th_alternativa'),
-                            translation_pss('Tipo de teste de acordo com hipótese alternativa:', linguagem()),
+                            translation_pss('Tipo de teste de acordo com hipótese alternativa', linguagem()),
                             choices = h1(),
                             selected = 'Bilateral'
-                ) %>% .help_buttom(body = txt_ajuda()$txt_h1)
+                ) |> .help_buttom(linguagem = linguagem(), body = txt_ajuda()$txt_h1)
               ))
             } else {
               numericInput( ns("confianca"),
@@ -139,7 +144,7 @@ mod_2_medias_dependentes_server <- function(id, tipo = "tamanho_amostral", txt_a
                             min = 0,
                             max = 100,
                             step = 1
-              ) %>% .help_buttom(body = txt_ajuda()$txt_confianca, title = translation_pss("Nível de confiança (%)", linguagem()))
+              ) |> .help_buttom(linguagem = linguagem(), body = txt_ajuda()$txt_confianca, title = translation_pss("Nível de confiança (%)", linguagem()))
             },
 
 
@@ -151,12 +156,12 @@ mod_2_medias_dependentes_server <- function(id, tipo = "tamanho_amostral", txt_a
                             min = 0,
                             max = 100,
                             step = 1
-              ) %>% .help_buttom(body = txt_ajuda()$txt_perdas_recusas, title = translation_pss("Perdas/ Recusas (%)", linguagem()))
+              ) |> .help_buttom(linguagem = linguagem(), body = txt_ajuda()$txt_perdas_recusas, title = translation_pss("Perdas/ Recusas (%)", linguagem()))
             }
           ),
 
           mainPanel(
-            htmlOutput(ns("texto_principal")) %>%
+            htmlOutput(ns("texto_principal")) |>
               shinycssloaders::withSpinner(type = 5),
 
               uiOutput(ns("cenarios"))
@@ -218,7 +223,7 @@ mod_2_medias_dependentes_server <- function(id, tipo = "tamanho_amostral", txt_a
 
               htmlOutput(ns("resultado"))
             ),
-            title = translation_pss("Obter o desvio padrão combinado", linguagem()),
+            title = translation_pss("Obter o desvio padrão da diferença", linguagem()),
             easyClose = TRUE,
             footer    = NULL,
             size      = "m"
@@ -390,28 +395,33 @@ mod_2_medias_dependentes_server <- function(id, tipo = "tamanho_amostral", txt_a
           if (tipo == "tamanho_amostral") {
             paste0(
               "<b><font size = '5'>", translation_pss("Tamanho amostral calculado", linguagem()), ": ", n,
-              "</font></b></br></br><i>", translation_pss("Sugestão de texto", linguagem()), ":</i></br></br>",
-              "Foi calculado um tamanho de amostra de <b>", n, "</b> pares ",
+              "</font></b></br></br>",
 
-              if (th_alternativa() == "two.sided") {
-                paste0(
-                  " para testar se existe uma diferença mínima de <b>", input$diferenca_para_detectar, " ", unidade_medida(), "</b> ",
-                  "na média das diferenças de <i>",
-                  nome_desfecho(), "</i> entre os grupos <i>", nome_grupo_controle(), "</i> e <i>", nome_grupo_tratamento(), "</i> "
-                )
-              } else {
-                paste0(
-                  "para testar se  a média das diferenças de <i>", nome_desfecho(), "</i> entre os grupos <i>", nome_grupo_controle(), "</i> e <i>", nome_grupo_tratamento(), "</i> é ",
-                  ifelse(th_alternativa() == "less", "menor", "maior"),
-                  " do que zero "
-                )
-              },
 
-              "(com o acréscimo de <b>", input$perc_perdas, "%</b> para possíveis perdas e recusas este número deve ser <b>", n_perdas(n, input$perc_perdas), "</b>). ",
-              "O cálculo considerou poder de <b>", input$poder, "%</b>, nível de significância de <b>", input$alpha, "%</b>, ",
-              "média e desvio padrão das diferenças iguais a <b>", input$diferenca_para_detectar,
-              "</b> e <b>", input$sigma, " ", unidade_medida(), "</b>, respectivamente (referido por Fulano (1900)). ",
-              .txt_citacao_pss,
+              lista_de_funcoes_server()$sugestao_texto_portugues(
+                "<i>",
+                translation_pss("Sugestão de texto", linguagem()), ":</i></br></br>",
+                "Foi calculado um tamanho de amostra de <b>", n, "</b> pares ",
+
+                if (th_alternativa() == "two.sided") {
+                  paste0(
+                    " para testar se existe uma diferença mínima de <b>", input$diferenca_para_detectar, " ", unidade_medida(), "</b> ",
+                    "na média das diferenças de <i>",
+                    nome_desfecho(), "</i> entre os grupos <i>", nome_grupo_controle(), "</i> e <i>", nome_grupo_tratamento(), "</i> "
+                  )
+                } else {
+                  paste0(
+                    "para testar se  a média das diferenças de <i>", nome_desfecho(), "</i> entre os grupos <i>", nome_grupo_controle(), "</i> e <i>", nome_grupo_tratamento(), "</i> é ",
+                    ifelse(th_alternativa() == "less", "menor", "maior"),
+                    " do que zero "
+                  )
+                },
+
+                "(com o acréscimo de <b>", input$perc_perdas, "%</b> para possíveis perdas e recusas este número deve ser <b>", n_perdas(n, input$perc_perdas), "</b>). ",
+                "O cálculo considerou poder de <b>", input$poder, "%</b>, nível de significância de <b>", input$alpha, "%</b> ",
+                " e desvio padrão das diferenças igual a <b>", input$sigma, " ", unidade_medida(), "</b> (Fulano (1900)). ",
+                .txt_citacao_pss
+              ),
               .txt_referencia_tap,
               print_r_code(code)
             )
@@ -421,27 +431,31 @@ mod_2_medias_dependentes_server <- function(id, tipo = "tamanho_amostral", txt_a
           } else if (tipo == "poder") {
             paste0(
               "<b><font size = '5'>", translation_pss("Poder calculado", linguagem()), ": ", n, "%",
-              "</font></b></br></br><i>", translation_pss("Sugestão de texto", linguagem()), ":</i></br></br>",
-              "O poder",
-              if (th_alternativa() == "two.sided") {
-                paste0(
-                  " para testar se existe uma diferença mínima de <b>", input$diferenca_para_detectar, " ", unidade_medida(), "</b> ",
-                  "na média das diferenças de <i>",
-                  nome_desfecho(), "</i> entre os grupos <i>", nome_grupo_controle(), "</i> e <i>", nome_grupo_tratamento(), "</i> "
-                )
-              } else {
-                paste0(
-                  "para testar se  a média das diferenças de <i>", nome_desfecho(), "</i> entre os grupos <i>", nome_grupo_controle(), "</i> e <i>", nome_grupo_tratamento(), "</i> é ",
-                  ifelse(th_alternativa() == "less", "menor", "maior"),
-                  " do que zero "
-                )
-              },
-              "é de <b>", n, "%</b>. ",
-              "Este valor foi obtido considerando nível de significância de <b>", input$alpha, "%</b>, ",
-              "tamanho amostral igual a <b>", input$n, "</b> pares, ",
-              "média e desvio padrão das diferenças iguais a <b>", input$diferenca_para_detectar,
-              "</b> e <b>", input$sigma, " ", unidade_medida(), "</b>, respectivamente (referido por Fulano (1900)). ",
-              .txt_citacao_pss,
+              "</font></b></br></br><i>",
+
+
+              lista_de_funcoes_server()$sugestao_texto_portugues(
+                translation_pss("Sugestão de texto", linguagem()), ":</i></br></br>",
+                "O poder",
+                if (th_alternativa() == "two.sided") {
+                  paste0(
+                    " para testar se existe uma diferença mínima de <b>", input$diferenca_para_detectar, " ", unidade_medida(), "</b> ",
+                    "na média das diferenças de <i>",
+                    nome_desfecho(), "</i> entre os grupos <i>", nome_grupo_controle(), "</i> e <i>", nome_grupo_tratamento(), "</i> "
+                  )
+                } else {
+                  paste0(
+                    " para testar se  a média das diferenças de <i>", nome_desfecho(), "</i> entre os grupos <i>", nome_grupo_controle(), "</i> e <i>", nome_grupo_tratamento(), "</i> é ",
+                    ifelse(th_alternativa() == "less", "menor", "maior"),
+                    " do que zero "
+                  )
+                },
+                "é de <b>", n, "%</b>. ",
+                "Este valor foi obtido considerando nível de significância de <b>", input$alpha, "%</b>, ",
+                "tamanho amostral igual a <b>", input$n, "</b> pares, ",
+                " e desvio padrão das diferenças igual a <b>", input$sigma, " ", unidade_medida(), "</b> (Fulano (1900)). ",
+                .txt_citacao_pss
+                ),
               .txt_referencia_tap,
               print_r_code(code)
 
@@ -451,16 +465,20 @@ mod_2_medias_dependentes_server <- function(id, tipo = "tamanho_amostral", txt_a
 
             paste0(
               "<b><font size = '5'>", translation_pss("Tamanho amostral calculado", linguagem()), ": ", n,
-              "</font></b></br></br><i>", translation_pss("Sugestão de texto", linguagem()), ":</i></br></br>",
+              "</font></b></br></br><i>",
 
-              "Foi calculado um tamanho de amostra de <b>", n, "</b> pares  para estimar a média das diferenças de <i>",
-              nome_desfecho(), "</i> entre os grupos <i>", nome_grupo_controle(), "</i> e <i>", nome_grupo_tratamento(), "</i>, ",
-              "com margem de erro  igual a <b>", input$precisao, " ", unidade_medida(), "</b> ",
-              "(com o acréscimo de <b>", input$perc_perdas, "%</b> para possíveis perdas e recusas este número deve ser <b>", n_perdas(n, input$perc_perdas), "</b>). ",
+              lista_de_funcoes_server()$sugestao_texto_portugues(
+                translation_pss("Sugestão de texto", linguagem()), ":</i></br></br>",
 
-              "O cálculo considerou nível de confiança de <b>", input$confianca, "</b>%  e ",
-              "desvio padrão das diferenças iguais a <b>", input$sigma, " ", unidade_medida(), "</b> (referido por Fulano (1900)). ",
-              .txt_citacao_pss,
+                "Foi calculado um tamanho de amostra de <b>", n, "</b> pares  para estimar a média das diferenças de <i>",
+                nome_desfecho(), "</i> entre os grupos <i>", nome_grupo_controle(), "</i> e <i>", nome_grupo_tratamento(), "</i>, ",
+                "com margem de erro  igual a <b>", input$precisao, " ", unidade_medida(), "</b> ",
+                "(com o acréscimo de <b>", input$perc_perdas, "%</b> para possíveis perdas e recusas este número deve ser <b>", n_perdas(n, input$perc_perdas), "</b>). ",
+
+                "O cálculo considerou nível de confiança de <b>", input$confianca, "</b>%  e ",
+                "desvio padrão das diferenças iguais a <b>", input$sigma, " ", unidade_medida(), "</b> (referido por Fulano (1900)). ",
+                .txt_citacao_pss
+              ),
               .txt_referencia_tap,
               print_r_code(code)
             )
@@ -507,7 +525,7 @@ mod_2_medias_dependentes_server <- function(id, tipo = "tamanho_amostral", txt_a
           HTML(
             "<b>",
             translation_pss("Defina a sequência de valores para a diferença a ser detectada", linguagem()),
-            ":</b>"
+            "</b>"
           ),
 
 
@@ -519,8 +537,8 @@ mod_2_medias_dependentes_server <- function(id, tipo = "tamanho_amostral", txt_a
               numericInput(ns("to"), translation_pss("Máximo", linguagem()), value = val_max, step = .5)
           ),
           div(style="display: inline-block;vertical-align:top; width: 80px;",
-              numericInput(ns("by"), translation_pss("Intervalo", linguagem()), value = 0.5, min = 0, step = .1) %>%
-                .help_buttom(body = translation_pss("Essa sequência será utilizada para compor o eixo x do gráfico. A sequência irá do valor <b>Mínimo</b> até o valor <b>Máximo</b> em intervalos definidos no <b>Intervalo</b>.", linguagem()),
+              numericInput(ns("by"), translation_pss("Intervalo", linguagem()), value = 0.5, min = 0, step = .1) |>
+                .help_buttom(linguagem = linguagem(), body = translation_pss("Essa sequência será utilizada para compor o eixo x do gráfico. A sequência irá do valor <b>Mínimo</b> até o valor <b>Máximo</b> em intervalos definidos no <b>Intervalo</b>.", linguagem()),
                              title = "Sequência")
           ),
 
@@ -528,19 +546,19 @@ mod_2_medias_dependentes_server <- function(id, tipo = "tamanho_amostral", txt_a
           fluidRow(
             column(6,
                    textInput(inputId = ns("desvio_cenarios"),
-                             label   = translation_pss("Digite valores de desvio padrão (DP) para fazer o gráfico:", linguagem()),
+                             label   = translation_pss("Digite valores de desvio padrão para fazer o gráfico", linguagem()),
                              value   = paste0(c(input$sigma, input$sigma + 0.2, input$sigma + 0.5), collapse = ", "),
-                             width   = "400px") %>%
-                     .help_buttom(body = ajuda_cenarios_multiplos_valores())
+                             width   = "400px") |>
+                     .help_buttom(linguagem = linguagem(), body = ajuda_cenarios_multiplos_valores())
             )
           ),
 
-          plotly::plotlyOutput(ns("grafico_cenarios"), width = "80%") %>%
+          plotly::plotlyOutput(ns("grafico_cenarios"), width = "80%") |>
             shinycssloaders::withSpinner(type = 5),
 
           br(), br(),
           downloadButton(ns("download_tabela_cenarios"), translation_pss("Download tabela", linguagem())),
-          DT::dataTableOutput(ns("tabela_cenarios"), width = "100%") %>%
+          DT::dataTableOutput(ns("tabela_cenarios"), width = "100%") |>
             shinycssloaders::withSpinner(type = 5)
 
         ))
@@ -563,7 +581,7 @@ mod_2_medias_dependentes_server <- function(id, tipo = "tamanho_amostral", txt_a
                     poder = input$poder,
                     alpha =  input$alpha,
                     alternativa = ifelse(th_alternativa() == "two.sided", "two.sided", "one.sided"),
-                    stringsAsFactors = FALSE) %>%
+                    stringsAsFactors = FALSE) |>
 
 
           mutate(n = mapply(
@@ -592,11 +610,11 @@ mod_2_medias_dependentes_server <- function(id, tipo = "tamanho_amostral", txt_a
         desvio <- "DP"
         names(desvio) <- translation_pss("DP", linguagem())
 
-        g1 <- tab_TH_cenarios() %>%
+        g1 <- tab_TH_cenarios() |>
           mutate(
             DP = factor(desvio)
-          ) %>%
-          dplyr::rename(all_of(desvio)) %>%
+          ) |>
+          dplyr::rename(all_of(desvio)) |>
           ggplot(
             aes(x = diferenca,
                 y = n,
@@ -610,11 +628,14 @@ mod_2_medias_dependentes_server <- function(id, tipo = "tamanho_amostral", txt_a
           ylab(translation_pss("Tamanho da amostra*", linguagem())) +
           theme_bw() +
           theme(axis.text = element_text(colour = "black")) +
-          scale_color_brewer(palette = "Set1")
+          scale_color_brewer(
+            name = translation_pss("Desvio padrão", linguagem()),
+            palette = "Set1"
+          )
 
 
         plotly::ggplotly(g1,
-                         tooltip = c("x", "colour", "y")) %>%
+                         tooltip = c("x", "colour", "y")) |>
           plotly::layout(annotations = list(x = 1, y = -0.1, text = translation_pss("* sem considerar perdas/ recusas.", linguagem()),
                                             showarrow = F, xref='paper', yref='paper',
                                             xanchor='right', yanchor='auto', xshift=0, yshift=0,
@@ -645,7 +666,7 @@ mod_2_medias_dependentes_server <- function(id, tipo = "tamanho_amostral", txt_a
 
       output$tabela_cenarios <- DT::renderDataTable({
 
-        return_table_tabela_cenarios() %>%
+        return_table_tabela_cenarios() |>
           DT::datatable(extensions = c('FixedColumns'),
                         rownames   = FALSE,
                         filter     = "none",
