@@ -5,7 +5,7 @@ mod_nao_inferioridade_Ui <- function(id){
 
   tagList(
 
-    uiOutput(ns("aba")) %>%
+    uiOutput(ns("aba")) |>
       shinycssloaders::withSpinner(type = 5)
 
   )# Fecha tagList
@@ -17,7 +17,8 @@ mod_nao_inferioridade_Ui <- function(id){
 mod_nao_inferioridade_server <- function(id, tipo = "tamanho_amostral", tipo_variavel = "c",
                                          txt_ajuda, txt_balanceamento_f,
                                          translation_pss, linguagem, .rodape, try_n, validate_n, ajuda_cenarios_multiplos_valores, validate_n_inf, n_perdas, print_r_code, text_input_to_vector, check_text_input_to_vector,
-                                         warning_prop, warning_numero_positivo, warning_inteiro, warning_perdas, warning_numero){
+                                         warning_prop, warning_numero_positivo, warning_inteiro, warning_perdas, warning_numero,
+                                         lista_de_funcoes_server){
   shiny::moduleServer(
     id,
     function(input, output, session){
@@ -81,7 +82,7 @@ mod_nao_inferioridade_server <- function(id, tipo = "tamanho_amostral", tipo_var
               choices = opcoes_testes_equivalencia(),
               selected = 'inf'
             ),
-              # .help_buttom(
+              # .help_buttom(linguagem = linguagem(),
               #   body = txt_ajuda()$txt_confianca,
               #   title = translation_pss("Nível de confiança (%)", linguagem())
               # ),
@@ -89,7 +90,7 @@ mod_nao_inferioridade_server <- function(id, tipo = "tamanho_amostral", tipo_var
           ),
 
           mainPanel(
-            htmlOutput(ns("texto_principal")) %>%
+            htmlOutput(ns("texto_principal")) |>
               shinycssloaders::withSpinner(type = 5)
           )
         )
@@ -160,8 +161,8 @@ mod_nao_inferioridade_server <- function(id, tipo = "tamanho_amostral", tipo_var
                         value = valor_margem_padrao,
                         min   = valor_margem_min,
                         max   = valor_margem_max,
-                        step  = 1) %>%
-            .help_buttom(
+                        step  = 1) |>
+            .help_buttom(linguagem = linguagem(),
               body = case_when(input$opcoes_teste == "inf"  ~ txt_ajuda()$txt_margem_nao_inferior,
                                input$opcoes_teste == "sup"  ~ txt_ajuda()$txt_margem_superior,
                                TRUE ~ txt_ajuda()$txt_margem_equivalencia),
@@ -181,7 +182,7 @@ mod_nao_inferioridade_server <- function(id, tipo = "tamanho_amostral", tipo_var
                             min = -Inf,
                             max = Inf,
                             step = .5
-              ) %>% .help_buttom(body = txt_ajuda()$txt_diferenca_clinica, title = translation_pss("Diferença mínima a ser detectada", linguagem())),
+              ) |> .help_buttom(linguagem = linguagem(), body = txt_ajuda()$txt_diferenca_clinica, title = translation_pss("Diferença mínima a ser detectada", linguagem())),
 
               numericInput( ns("sigma"),
                             translation_pss("Desvio padrão", linguagem()),
@@ -189,7 +190,7 @@ mod_nao_inferioridade_server <- function(id, tipo = "tamanho_amostral", tipo_var
                             min = 0,
                             max = Inf,
                             step = 1
-              ) %>% .help_buttom(body = txt_ajuda()$txt_dp, title = translation_pss("Desvio padrão", linguagem())),
+              ) |> .help_buttom(linguagem = linguagem(), body = txt_ajuda()$txt_dp, title = translation_pss("Desvio padrão", linguagem())),
 
               actionLink(ns("show_desvio_combinado"), translation_pss("Calcular o desvio padrão combinado", linguagem())),
               br(), br()
@@ -206,7 +207,7 @@ mod_nao_inferioridade_server <- function(id, tipo = "tamanho_amostral", tipo_var
                             min = 0,
                             max = 100,
                             step = 1
-              ) %>% .help_buttom(body = txt_ajuda()$txt_perc_esperado),
+              ) |> .help_buttom(linguagem = linguagem(), body = txt_ajuda()$txt_perc_esperado),
 
               wellPanel(
                 selectInput(
@@ -236,7 +237,7 @@ mod_nao_inferioridade_server <- function(id, tipo = "tamanho_amostral", tipo_var
                           min   = 0,
                           max   = Inf,
                           step  = .5
-            ) %>% .help_buttom(body = txt_balanceamento_f(nome_grupo_tratamento(), nome_grupo_controle()),
+            ) |> .help_buttom(linguagem = linguagem(), body = txt_balanceamento_f(nome_grupo_tratamento(), nome_grupo_controle()),
                                title = translation_pss("Balanceamento", linguagem()))
           },
 
@@ -272,7 +273,7 @@ mod_nao_inferioridade_server <- function(id, tipo = "tamanho_amostral", tipo_var
                           min = 0,
                           max = 100,
                           step = 1
-            ) %>% .help_buttom(body = txt_ajuda()$txt_power, title = translation_pss("Poder (%)", linguagem()))
+            ) |> .help_buttom(linguagem = linguagem(), body = txt_ajuda()$txt_power, title = translation_pss("Poder (%)", linguagem()))
           },
 
 
@@ -282,7 +283,7 @@ mod_nao_inferioridade_server <- function(id, tipo = "tamanho_amostral", tipo_var
                         min = 0,
                         max = 100,
                         step = 1
-          ) %>% .help_buttom(body = txt_ajuda()$txt_significancia, title = translation_pss("Nível de significância (%)", linguagem())),
+          ) |> .help_buttom(linguagem = linguagem(), body = txt_ajuda()$txt_significancia, title = translation_pss("Nível de significância (%)", linguagem())),
 
 
           if (tipo %in% c("tamanho_amostral")) {
@@ -292,7 +293,7 @@ mod_nao_inferioridade_server <- function(id, tipo = "tamanho_amostral", tipo_var
                           min = 0,
                           max = 100,
                           step = 1
-            ) %>% .help_buttom(body = txt_ajuda()$txt_perdas_recusas, title = translation_pss("Perdas/ Recusas (%)", linguagem()))
+            ) |> .help_buttom(linguagem = linguagem(), body = txt_ajuda()$txt_perdas_recusas, title = translation_pss("Perdas/ Recusas (%)", linguagem()))
           }
         )
       })
@@ -341,7 +342,7 @@ mod_nao_inferioridade_server <- function(id, tipo = "tamanho_amostral", tipo_var
                           min = 0,
                           max = 100,
                           step = 1
-            ) %>% .help_buttom(body = txt_ajuda()$txt_perc_esperado)
+            ) |> .help_buttom(linguagem = linguagem(), body = txt_ajuda()$txt_perc_esperado)
 
           } else if (input$estatistica_tratamento == "ratio"){
             numericInput( ns("rr"),
@@ -350,7 +351,7 @@ mod_nao_inferioridade_server <- function(id, tipo = "tamanho_amostral", tipo_var
                           min = 0,
                           max = Inf,
                           step = 0.1
-            )  %>% .help_buttom(
+            )  |> .help_buttom(linguagem = linguagem(),
               body = txt_ajuda()$txt_risco_relativo,
               title = translation_pss("Risco relativo", linguagem())
             )
@@ -361,7 +362,7 @@ mod_nao_inferioridade_server <- function(id, tipo = "tamanho_amostral", tipo_var
                           min = 0,
                           max = Inf,
                           step = 0.1
-            ) %>% .help_buttom(body = txt_ajuda()$txt_razao_chance, title = translation_pss("Razão de chance", linguagem()))
+            ) |> .help_buttom(linguagem = linguagem(), body = txt_ajuda()$txt_razao_chance, title = translation_pss("Razão de chance", linguagem()))
           }
         )
       })
@@ -446,7 +447,7 @@ mod_nao_inferioridade_server <- function(id, tipo = "tamanho_amostral", tipo_var
         s2b <- input$sigma_B^2
 
         n1 <- input$n_A
-        n2 <- input$n_A
+        n2 <- input$n_B
 
         numerador   <- (n1 - 1)*s2a + (n2 - 1)*s2b
         denominador <- n1 + n2 - 2
@@ -468,7 +469,7 @@ mod_nao_inferioridade_server <- function(id, tipo = "tamanho_amostral", tipo_var
 
       output$th_h0 <- renderUI({
 
-        paramentro <- ifelse(tipo_variavel == "c", "\\mu_{", "\\pi_{")
+        paramentro <- ifelse(tipo_variavel == "c", "\\mu_\\text{", "\\pi_\\text{")
 
         if (input$opcoes_teste %in% c("inf", "sup")) {
           withMathJax(
@@ -490,7 +491,7 @@ mod_nao_inferioridade_server <- function(id, tipo = "tamanho_amostral", tipo_var
       })
 
       output$th_h1 <- renderUI({
-        paramentro <- ifelse(tipo_variavel == "c", "\\mu_{", "\\pi_{")
+        paramentro <- ifelse(tipo_variavel == "c", "\\mu_\\text{", "\\pi_\\text{")
 
         if (input$opcoes_teste %in% c("inf", "sup")) {
           withMathJax(
@@ -772,94 +773,99 @@ mod_nao_inferioridade_server <- function(id, tipo = "tamanho_amostral", tipo_var
               "<b><font size = '5'>", translation_pss("Tamanho amostral calculado", linguagem()), ": ", n,
               if (n1 != n2) {
                 paste0(
-                  " (<i>", n1, " ", nome_grupo_tratamento(), " e ", n2, " ", nome_grupo_controle(), "</i>)"
+                  " (<i>", n1, " ", nome_grupo_tratamento(),
+                  translation_pss(" e ", linguagem()),
+                  n2, " ", nome_grupo_controle(), "</i>)"
                 )
               } else {
                 paste0(
-                  " (<i>", n1, " para cada grupo</i>)"
+                  " (<i>", n1, " ", translation_pss("para cada grupo", linguagem()), "</i>)"
                 )
               }
             )
           } else if (tipo == "poder") {
             paste0("<b><font size = '5'>", translation_pss("Poder calculado", linguagem()), ": ", poder, "%")
           },
+          "</font></b></br></br>",
 
 
-
-          "</font></b></br></br><i>", translation_pss("Sugestão de texto", linguagem()), ":</i></br></br>",
+          lista_de_funcoes_server()$sugestao_texto_portugues(
+            "<i>",
+            translation_pss("Sugestão de texto", linguagem()), ":</i></br></br>",
 
 
-          # Inicio do texto
+            # Inicio do texto
 
-          if (tipo == "tamanho_amostral") {
-            paste0(
-              "Foi calculado um tamanho de amostra de <b>", n, "</b> sujeitos ",
-              if (n1 != n2) {
-                paste0(
-                  "(", n1, " no grupo ", nome_grupo_tratamento(), " e ", n2, " no grupo ", nome_grupo_controle(), ")"
-                )
+            if (tipo == "tamanho_amostral") {
+              paste0(
+                "Foi calculado um tamanho de amostra de <b>", n, "</b> sujeitos ",
+                if (n1 != n2) {
+                  paste0(
+                    "(", n1, " no grupo ", nome_grupo_tratamento(), " e ", n2, " no grupo ", nome_grupo_controle(), ")"
+                  )
+                } else {
+                  paste0(
+                    "(", n1, " para cada grupo)"
+                  )
+                }
+              )
+            } else if (tipo == "poder") {
+              "O poder"
+            },
+
+            " para testar a ", teste_escolhido,
+
+
+            if (tipo_variavel == "c") ", em termos de médias de <i>" else  ", em termos de proporção de <i>",
+            nome_desfecho(), "</i>, do grupo <i>", nome_grupo_tratamento(),
+            "</i> em relação ao grupo <i>", nome_grupo_controle(), "</i> ",
+
+
+            if (tipo == "tamanho_amostral") {
+              if (input$balanceamento == 1) {
+                paste0("(com o acréscimo de <b>", input$perc_perdas, "%</b> para possíveis perdas e recusas este número deve ser <b>", nperdas1 + nperdas2, "</b>). ")
               } else {
-                paste0(
-                  "(", n1, " para cada grupo)"
-                )
+                paste0("(com o acréscimo de <b>", input$perc_perdas, "%</b> para possíveis perdas e recusas este número deve ser ", nperdas1, " ", nome_grupo_tratamento(), " e ", nperdas2, " ", nome_grupo_controle(), "). ")
               }
-            )
-          } else if (tipo == "poder") {
-            "O poder"
-          },
-
-          " para testar a ", teste_escolhido,
-
-
-          if (tipo_variavel == "c") ", em termos de médias de <i>" else  ", em termos de proporção de <i>",
-          nome_desfecho(), "</i>, do grupo <i>", nome_grupo_tratamento(),
-          "</i> em relação ao grupo <i>", nome_grupo_controle(), "</i> ",
-
-
-          if (tipo == "tamanho_amostral") {
-            if (input$balanceamento == 1) {
-              paste0("(com o acréscimo de <b>", input$perc_perdas, "%</b> para possíveis perdas e recusas este número deve ser <b>", nperdas1 + nperdas2, "</b>). ")
             } else {
-              paste0("(com o acréscimo de <b>", input$perc_perdas, "%</b> para possíveis perdas e recusas este número deve ser ", nperdas1, " ", nome_grupo_tratamento(), " e ", nperdas2, " ", nome_grupo_controle(), "). ")
-            }
-          } else {
-            paste0("é de <b>", poder, "%</b>. ")
-          },
+              paste0("é de <b>", poder, "%</b>. ")
+            },
 
 
-          if (tipo == "tamanho_amostral") {
-            paste0(
-              "O cálculo considerou como margem de ", teste_escolhido, " <b>", input$margem,
+            if (tipo == "tamanho_amostral") {
+              paste0(
+                "O cálculo considerou como margem de ", teste_escolhido, " <b>", input$margem,
 
-              if (tipo_variavel == "c") paste0(" ", unidade_medida(), "</b>, ") else paste0("%</b>, "),
-              "poder de <b>", input$poder, "%</b>, nível de significância de <b>", input$alpha, "%</b>, "
-            )
-          } else if (tipo == "poder") {
-            paste0(
-              "Este valor foi obtido considerando margem de ", teste_escolhido, " </b>", input$margem,
-              if (tipo_variavel == "c") paste0(" ", unidade_medida(), "</b>, ") else paste0(" %</b>, "),
-              "nível de significância de <b>", input$alpha, "%</b>, ",
-              if (input$n_tratamento == input$n_controle) {
-                paste0("tamanho amostral igual a <b>", input$n_controle, "</b> sujeitos em cada grupo, ")
-              } else {
-                paste0(
-                  "tamanho amostral igual a <b>", input$n_tratamento, "</b> sujeitos para o grupo <i>",
-                  nome_grupo_tratamento(), "</i> e <b>", input$n_controle, "</b> sujeitos para o grupo <i>",
-                  nome_grupo_controle(), "</i> "
-                )
-              }
-            )
-          },
+                if (tipo_variavel == "c") paste0(" ", unidade_medida(), "</b>, ") else paste0("%</b>, "),
+                "poder de <b>", input$poder, "%</b>, nível de significância de <b>", input$alpha, "%</b>, "
+              )
+            } else if (tipo == "poder") {
+              paste0(
+                "Este valor foi obtido considerando margem de ", teste_escolhido, " </b>", input$margem,
+                if (tipo_variavel == "c") paste0(" ", unidade_medida(), "</b>, ") else paste0(" %</b>, "),
+                "nível de significância de <b>", input$alpha, "%</b>, ",
+                if (input$n_tratamento == input$n_controle) {
+                  paste0("tamanho amostral igual a <b>", input$n_controle, "</b> sujeitos em cada grupo, ")
+                } else {
+                  paste0(
+                    "tamanho amostral igual a <b>", input$n_tratamento, "</b> sujeitos para o grupo <i>",
+                    nome_grupo_tratamento(), "</i> e <b>", input$n_controle, "</b> sujeitos para o grupo <i>",
+                    nome_grupo_controle(), "</i> "
+                  )
+                }
+              )
+            },
 
-          if (tipo_variavel == "c") {
-            paste0(
-              "diferença de <b>", input$diferenca_para_detectar, " ", unidade_medida(), "</b> entre as médias e ",
-              "desvio padrão igual a <b>", input$sigma, " ", unidade_medida(), "</b> (referido por Fulano (1900)). "
-            )
-          } else {
-            text_just
-          },
-          .txt_citacao_pss,
+            if (tipo_variavel == "c") {
+              paste0(
+                "diferença de <b>", input$diferenca_para_detectar, " ", unidade_medida(), "</b> entre as médias e ",
+                "desvio padrão igual a <b>", input$sigma, " ", unidade_medida(), "</b> (referido por Fulano (1900)). "
+              )
+            } else {
+              text_just
+            },
+            .txt_citacao_pss
+          ),
           .txt_referencia_tap,
           print_r_code(code)
         )
