@@ -5,7 +5,7 @@ mod_regressao_logistica_Ui <- function(id) {
 
   tagList(
 
-    uiOutput(ns("aba_regressao_logistica")) %>%
+    uiOutput(ns("aba_regressao_logistica")) |>
       shinycssloaders::withSpinner(type = 5)
 
   )# Fecha tagList
@@ -16,7 +16,8 @@ mod_regressao_logistica_Ui <- function(id) {
 
 mod_regressao_logistica_server <- function(id, tipo = "tamanho_amostral", txt_ajuda, txt_balanceamento_f,
                                            translation_pss, linguagem, .rodape, try_n, validate_n, ajuda_cenarios_multiplos_valores, validate_n_inf, n_perdas, print_r_code, text_input_to_vector, check_text_input_to_vector,
-                                           warning_prop, warning_numero_positivo, warning_inteiro, warning_perdas) {
+                                           warning_prop, warning_numero_positivo, warning_inteiro, warning_perdas,
+                                           lista_de_funcoes_server) {
   shiny::moduleServer(
     id,
     function(input, output, session) {
@@ -61,12 +62,36 @@ mod_regressao_logistica_server <- function(id, tipo = "tamanho_amostral", txt_aj
 
 
 
+
+
+      opcoes_metodos_estimacao <- reactive({
+        choices <- c(
+          "Logit suavizado" = "indip_smooth",
+          "Gart" = "gart",
+          "Woolf" = "woolf"
+        )
+
+        if (linguagem() == "en") {
+          names(choices) <- c("Independence-smoothed logit", "Gart", "Woolf")
+        }
+
+        choices
+      })
+
+
+
       output$aba_regressao_logistica <- renderUI({
         req(!is.null(opcoes_tipo_variavel()))
 
         sidebarLayout(
           sidebarPanel(
 
+            wellPanel(HTML(
+              '<b><a href="https://youtu.be/wPuUns9pRTA" target="_blank">',
+              translation_pss("Vídeo: PSS Health para regressão logística com preditor quantitativo", linguagem()),
+              '</a></b><br>'
+            )),
+
             if (tipo %in% c("tamanho_amostral", "poder")) {
               tagList(
                 wellPanel(
@@ -96,7 +121,7 @@ mod_regressao_logistica_server <- function(id, tipo = "tamanho_amostral", txt_aj
                             value = 1.5,
                             min = 0,
                             step = 0.1
-              ) %>% .help_buttom(body = txt_ajuda()$txt_amplitude, title = translation_pss("Amplitude do intervalo", linguagem()))
+              ) |> .help_buttom(linguagem = linguagem(), body = txt_ajuda()$txt_amplitude, title = translation_pss("Amplitude do intervalo", linguagem()))
             },
 
             # uiOutput(ns("render_input_medida_controle")),
@@ -111,7 +136,7 @@ mod_regressao_logistica_server <- function(id, tipo = "tamanho_amostral", txt_aj
                             min = 0,
                             max = 100,
                             step = 1
-              ) %>% .help_buttom(body = txt_ajuda()$txt_power, title = translation_pss("Poder (%)", linguagem()))
+              ) |> .help_buttom(linguagem = linguagem(), body = txt_ajuda()$txt_power, title = translation_pss("Poder (%)", linguagem()))
             },
 
             if (tipo %in% c("tamanho_amostral", "poder")) {
@@ -121,7 +146,7 @@ mod_regressao_logistica_server <- function(id, tipo = "tamanho_amostral", txt_aj
                             min = 0,
                             max = 100,
                             step = 1
-              ) %>% .help_buttom(body = txt_ajuda()$txt_significancia, title = translation_pss("Nível de significância (%)", linguagem()))
+              ) |> .help_buttom(linguagem = linguagem(), body = txt_ajuda()$txt_significancia, title = translation_pss("Nível de significância (%)", linguagem()))
             } else{
               tagList(
                 numericInput( ns("confianca"),
@@ -130,18 +155,14 @@ mod_regressao_logistica_server <- function(id, tipo = "tamanho_amostral", txt_aj
                               min = 0,
                               max = 100,
                               step = 1
-                ) %>% .help_buttom(body = txt_ajuda()$txt_confianca, title = translation_pss("Nível de confiança (%)", linguagem())),
+                ) |> .help_buttom(linguagem = linguagem(), body = txt_ajuda()$txt_confianca, title = translation_pss("Nível de confiança (%)", linguagem())),
 
                 selectInput(ns("metodo_estimacao"),
                             translation_pss("Método utilizado para calcular o intervalo de confiança", linguagem()),
-                            choices = c(
-                              "Logit suavizado" = "indip_smooth",
-                              "Gart" = "gart",
-                              "Woolf" = "woolf"
-                            ),
+                            choices = opcoes_metodos_estimacao(),
                             selected = "indip_smooth"
                 ) |>
-                  .help_buttom(body = txt_ajuda()$txt_per_method_presize)
+                  .help_buttom(linguagem = linguagem(), body = txt_ajuda()$txt_per_method_presize)
               )
             },
 
@@ -152,7 +173,7 @@ mod_regressao_logistica_server <- function(id, tipo = "tamanho_amostral", txt_aj
                             min = 0,
                             max = 100,
                             step = 1
-              ) %>% .help_buttom(body = txt_ajuda()$txt_perdas_recusas, title = translation_pss("Perdas/ Recusas (%)", linguagem()))
+              ) |> .help_buttom(linguagem = linguagem(), body = txt_ajuda()$txt_perdas_recusas, title = translation_pss("Perdas/ Recusas (%)", linguagem()))
             }
           ),
 
@@ -261,7 +282,7 @@ mod_regressao_logistica_server <- function(id, tipo = "tamanho_amostral", txt_aj
                           min = 0,
                           max = 100,
                           step = 1
-            ) %>% .help_buttom(body = txt_ajuda()$txt_perc_esperado),
+            ) |> .help_buttom(linguagem = linguagem(), body = txt_ajuda()$txt_perc_esperado),
 
             wellPanel(
               selectInput(
@@ -288,7 +309,7 @@ mod_regressao_logistica_server <- function(id, tipo = "tamanho_amostral", txt_aj
                           min = 0,
                           max = Inf,
                           step = 0.1
-            ) %>% .help_buttom(body = txt_ajuda()$txt_razao_chance, title = translation_pss("Razão de chance", linguagem())),
+            ) |> .help_buttom(linguagem = linguagem(), body = txt_ajuda()$txt_razao_chance, title = translation_pss("Razão de chance", linguagem())),
 
             numericInput( ns("logistic_rate_mean"),
                           ifelse(linguagem() == "pt",
@@ -309,7 +330,7 @@ mod_regressao_logistica_server <- function(id, tipo = "tamanho_amostral", txt_aj
                           min  = 0,
                           max  = 100,
                           step = 1
-            ) %>% .help_buttom(body = paste0("O percentual de eventos esperados na média da variável preditora contínua.", txt_ajuda()$txt_definido_pesquisador_OU_literatura))
+            ) |> .help_buttom(linguagem = linguagem(), body = paste0("O percentual de eventos esperados na média da variável preditora contínua.", txt_ajuda()$txt_definido_pesquisador_OU_literatura))
           )
         }
       })
@@ -356,7 +377,7 @@ mod_regressao_logistica_server <- function(id, tipo = "tamanho_amostral", txt_aj
                           min = 0,
                           max = 100,
                           step = 1
-            ) %>% .help_buttom(body = txt_ajuda()$txt_perc_esperado)
+            ) |> .help_buttom(linguagem = linguagem(), body = txt_ajuda()$txt_perc_esperado)
 
           } else if (input$estatistica_tratamento == "ratio") {
             numericInput( ns("rr"),
@@ -365,7 +386,7 @@ mod_regressao_logistica_server <- function(id, tipo = "tamanho_amostral", txt_aj
                           min = 0,
                           max = Inf,
                           step = 0.1
-            )  %>% .help_buttom(
+            )  |> .help_buttom(linguagem = linguagem(),
               body = txt_ajuda()$txt_risco_relativo,
               title = translation_pss("Risco relativo", linguagem())
             )
@@ -376,7 +397,7 @@ mod_regressao_logistica_server <- function(id, tipo = "tamanho_amostral", txt_aj
                           min = 0,
                           max = Inf,
                           step = 0.1
-            ) %>% .help_buttom(body = txt_ajuda()$txt_razao_chance, title = translation_pss("Razão de chance", linguagem()))
+            ) |> .help_buttom(linguagem = linguagem(), body = txt_ajuda()$txt_razao_chance, title = translation_pss("Razão de chance", linguagem()))
           }
 
         )
@@ -399,7 +420,7 @@ mod_regressao_logistica_server <- function(id, tipo = "tamanho_amostral", txt_aj
                         min   = 0,
                         max   = Inf,
                         step  = .5
-          ) %>% .help_buttom(txt_balanceamento_f(nome_grupo_controle(), nome_grupo_tratamento()),
+          ) |> .help_buttom(linguagem = linguagem(), txt_balanceamento_f(nome_grupo_controle(), nome_grupo_tratamento()),
                              title = translation_pss("Balanceamento", linguagem()))
         } else if (input$tipo_variavel == 0 & tipo == "poder") {
 
@@ -464,17 +485,22 @@ mod_regressao_logistica_server <- function(id, tipo = "tamanho_amostral", txt_aj
 
 
           paste0("<b><font size = '5'>", translation_pss("Tamanho amostral calculado", linguagem()), ": ", n,
-                 "</font></b></br></br><i>", translation_pss("Sugestão de texto", linguagem()), ":</i></br></br>",
+                 "</font></b></br></br>",
+
+                 lista_de_funcoes_server()$sugestao_texto_portugues(
+                   "<i>",
+                   translation_pss("Sugestão de texto", linguagem()), ":</i></br></br>",
 
 
-                 "Foi calculado um tamanho de amostra de <b>", n, "</b> sujeitos ",
-                 "para testar se a razão de chances para desenvolver <i>", nome_desfecho(), "</i> a cada acréscimo de uma unidade em <i>", nome_preditora(), "</i> é diferente de 1 ",
-                 "(com o acréscimo de ", input$perc_perdas, "% para possíveis perdas e recusas este número deve ser <b>", n_perdas(n, input$perc_perdas), "</b>). ",
-                 "O cálculo considerou um poder de <b>", input$poder, "%</b>, nível de significância de <b>", input$alpha, "%</b>, ",
-                 "percentual de <i>", nome_desfecho(), "</i> na média de <i>", nome_preditora(), "</i> de <b>", input$logistic_rate_mean, "%</b> ",
-                 "e razão de chances esperada de <b>", input$rc_continua, "</b> como é referida em Fulano (1900) OU escolha do pesquisador. ",
-                 .txt_citacao_pss,
-                 .txt_referencia_tap,
+                   "Foi calculado um tamanho de amostra de <b>", n, "</b> sujeitos ",
+                   "para testar se a razão de chances para desenvolver <i>", nome_desfecho(), "</i> a cada acréscimo de uma unidade em <i>", nome_preditora(), "</i> é diferente de 1 ",
+                   "(com o acréscimo de ", input$perc_perdas, "% para possíveis perdas e recusas este número deve ser <b>", n_perdas(n, input$perc_perdas), "</b>). ",
+                   "O cálculo considerou um poder de <b>", input$poder, "%</b>, nível de significância de <b>", input$alpha, "%</b>, ",
+                   "percentual de <i>", nome_desfecho(), "</i> na média de <i>", nome_preditora(), "</i> de <b>", input$logistic_rate_mean, "%</b> ",
+                   "e razão de chances esperada de <b>", input$rc_continua, "</b> como é referida em Fulano (1900) OU escolha do pesquisador. ",
+                   .txt_citacao_pss
+                 ),
+                   .txt_referencia_tap,
                  print_r_code(code)
           )
 
@@ -535,42 +561,47 @@ mod_regressao_logistica_server <- function(id, tipo = "tamanho_amostral", txt_aj
             "<b><font size = '5'>", translation_pss("Tamanho amostral calculado", linguagem()), ": ", n,
             if (n1 != n2) {
               paste0(
-                " (<i>", n1, " ", nome_grupo_tratamento(), " e ", n2, " ", nome_grupo_controle(), "</i>)"
+                " (<i>", n1, " ", nome_grupo_tratamento(), translation_pss(" e ", linguagem()), n2, " ", nome_grupo_controle(), "</i>)"
               )
             } else {
               paste0(
-                " (<i>", n1, " para cada grupo</i>)"
+                " (<i>", n1, " ", translation_pss("para cada grupo", linguagem()), "</i>)"
               )
             },
-            "</font></b></br></br><i>", translation_pss("Sugestão de texto", linguagem()), ":</i></br></br>",
+            "</font></b></br></br>",
+
+            lista_de_funcoes_server()$sugestao_texto_portugues(
+              "<i>",
+              translation_pss("Sugestão de texto", linguagem()), ":</i></br></br>",
 
 
-            "Foi calculado um tamanho de amostra de <b>", n , "</b> sujeitos, sendo <b>",
-            if (probs == 0.5) {
-              paste0(
-                n1, "</b> em cada grupo, "
-              )
-            } else {
-              paste0(
-                n1, "</b> no <i>", nome_grupo_tratamento(), "</i> e <b>", n2, "</b> no <i>", nome_grupo_controle(), "</i>, "
-              )
-            },
+              "Foi calculado um tamanho de amostra de <b>", n , "</b> sujeitos, sendo <b>",
+              if (probs == 0.5) {
+                paste0(
+                  n1, "</b> em cada grupo, "
+                )
+              } else {
+                paste0(
+                  n1, "</b> no <i>", nome_grupo_tratamento(), "</i> e <b>", n2, "</b> no <i>", nome_grupo_controle(), "</i>, "
+                )
+              },
 
-            "para testar se a razão de chances para desenvolver <i>",
-            nome_desfecho(), "</i> entre os grupos <i>",
-            nome_grupo_controle(), "</i> e <i>", nome_grupo_tratamento(),
-            "</i> é diferente de 1 ",
+              "para testar se a razão de chances para desenvolver <i>",
+              nome_desfecho(), "</i> entre os grupos <i>",
+              nome_grupo_controle(), "</i> e <i>", nome_grupo_tratamento(),
+              "</i> é diferente de 1 ",
 
-            if (probs == 0.5) {
-              paste0("(com o acréscimo de <b>", input$perc_perdas, "%</b> para possíveis perdas e recusas este número deve ser <b>", nperdas1 + nperdas2, "</b>). ")
-            } else {
-              paste0("(com o acréscimo de <b>", input$perc_perdas, "%</b> para possíveis perdas e recusas este número deve ser ", nperdas1, " <i>", nome_grupo_tratamento(), "</i> e ", nperdas2, " <i>", nome_grupo_controle(), "</i>). ")
-            },
+              if (probs == 0.5) {
+                paste0("(com o acréscimo de <b>", input$perc_perdas, "%</b> para possíveis perdas e recusas este número deve ser <b>", nperdas1 + nperdas2, "</b>). ")
+              } else {
+                paste0("(com o acréscimo de <b>", input$perc_perdas, "%</b> para possíveis perdas e recusas este número deve ser ", nperdas1, " <i>", nome_grupo_tratamento(), "</i> e ", nperdas2, " <i>", nome_grupo_controle(), "</i>). ")
+              },
 
-            "O cálculo considerou um poder de <b>", input$poder, "%</b>, nível de significância de <b>", input$alpha, "%</b>, ",
-            text_just,
+              "O cálculo considerou um poder de <b>", input$poder, "%</b>, nível de significância de <b>", input$alpha, "%</b>, ",
+              text_just,
 
-            .txt_citacao_pss,
+              .txt_citacao_pss
+            ),
             .txt_referencia_tap,
             print_r_code(code)
           )
@@ -604,14 +635,17 @@ mod_regressao_logistica_server <- function(id, tipo = "tamanho_amostral", txt_aj
             "<b><font size = '5'>", translation_pss("Poder calculado", linguagem()), ": ", round(poder*100, digits = 1),
             "%</font></b></br></br>",
 
-            "O poder para testar se a razão de chances para desenvolver <i>", nome_desfecho(), "</i> a cada acréscimo de uma unidade em <i>", nome_preditora(), "</i> é diferente de 1 é <b>",
-            round(poder*100, digits = 1), "%</b>. ",
+            lista_de_funcoes_server()$sugestao_texto_portugues(
+              # "<i>",
+              "O poder para testar se a razão de chances para desenvolver <i>", nome_desfecho(), "</i> a cada acréscimo de uma unidade em <i>", nome_preditora(), "</i> é diferente de 1 é <b>",
+              round(poder*100, digits = 1), "%</b>. ",
 
-            "Este valor foi obtido considerando nível de significância de <b>", input$alpha, "%</b>, ",
-            "tamanho amostral igual a <b>", input$n_total, "</b> sujeitos, ",
-            "percentual de <i>", nome_desfecho(), "</i> na média de <i>", nome_preditora(), "</i> de <b>", input$logistic_rate_mean, "%</b> ",
-            "e razão de chances esperada de <b>", input$rc_continua, "</b> como é referida em Fulano (1900) OU escolha do pesquisador. ",
-            .txt_citacao_pss,
+              "Este valor foi obtido considerando nível de significância de <b>", input$alpha, "%</b>, ",
+              "tamanho amostral igual a <b>", input$n_total, "</b> sujeitos, ",
+              "percentual de <i>", nome_desfecho(), "</i> na média de <i>", nome_preditora(), "</i> de <b>", input$logistic_rate_mean, "%</b> ",
+              "e razão de chances esperada de <b>", input$rc_continua, "</b> como é referida em Fulano (1900) OU escolha do pesquisador. ",
+              .txt_citacao_pss
+            ),
             .txt_referencia_tap,
             print_r_code(code)
           )
@@ -666,24 +700,27 @@ mod_regressao_logistica_server <- function(id, tipo = "tamanho_amostral", txt_aj
             "<b><font size = '5'>", translation_pss("Poder calculado", linguagem()), ": ", round(poder*100, digits = 1),
             "%</font></b></br></br>",
 
-            "O poder para testar se a razão de chances para desenvolver <i>",
-            nome_desfecho(), "</i> entre os grupos <i>",
-            nome_grupo_controle(), "</i> e <i>", nome_grupo_tratamento(),
-            "</i> é diferente de 1 é <b>", round(poder*100, digits = 1), "%</b>. ",
+            lista_de_funcoes_server()$sugestao_texto_portugues(
+              # "<i>",
+              "O poder para testar se a razão de chances para desenvolver <i>",
+              nome_desfecho(), "</i> entre os grupos <i>",
+              nome_grupo_controle(), "</i> e <i>", nome_grupo_tratamento(),
+              "</i> é diferente de 1 é <b>", round(poder*100, digits = 1), "%</b>. ",
 
-            "Este valor foi obtido considerando nível de significância de <b>", input$alpha, "%</b>, ",
-            if (input$n_tratamento == input$n_controle) {
-              paste0("tamanho amostral igual a <b>", input$n_controle, "</b> sujeitos em cada grupo, ")
-            } else {
-              paste0(
-                "tamanho amostral igual a <b>", input$n_tratamento, "</b> sujeitos para o grupo <i>",
-                nome_grupo_tratamento(), "</i>, <b>", input$n_controle, "</b> sujeitos para o grupo <i>",
-                nome_grupo_controle(), "</i>, "
-              )
-            },
-            text_just,
+              "Este valor foi obtido considerando nível de significância de <b>", input$alpha, "%</b>, ",
+              if (input$n_tratamento == input$n_controle) {
+                paste0("tamanho amostral igual a <b>", input$n_controle, "</b> sujeitos em cada grupo, ")
+              } else {
+                paste0(
+                  "tamanho amostral igual a <b>", input$n_tratamento, "</b> sujeitos para o grupo <i>",
+                  nome_grupo_tratamento(), "</i>, <b>", input$n_controle, "</b> sujeitos para o grupo <i>",
+                  nome_grupo_controle(), "</i>, "
+                )
+              },
+              text_just,
 
-            .txt_citacao_pss,
+              .txt_citacao_pss
+            ),
             .txt_referencia_tap,
             print_r_code(code)
           )
@@ -766,44 +803,49 @@ mod_regressao_logistica_server <- function(id, tipo = "tamanho_amostral", txt_aj
           "<b><font size = '5'>", translation_pss("Tamanho amostral calculado", linguagem()), ": ", n,
           if (n1 != n2) {
             paste0(
-              " (<i>", n1, " ", nome_grupo_tratamento(), " e ", n2, " ", nome_grupo_controle(), "</i>)"
+              " (<i>", n1, " ", nome_grupo_tratamento(), translation_pss(" e ", linguagem()), n2, " ", nome_grupo_controle(), "</i>)"
             )
           } else {
             paste0(
-              " (<i>", n1, " para cada grupo</i>)"
+              " (<i>", n1, " ", translation_pss("para cada grupo", linguagem()), "</i>)"
             )
           },
-          "</font></b></br></br><i>", translation_pss("Sugestão de texto", linguagem()), ":</i></br></br>",
+          "</font></b></br></br>",
+
+          lista_de_funcoes_server()$sugestao_texto_portugues(
+            "<i>",
+            translation_pss("Sugestão de texto", linguagem()), ":</i></br></br>",
 
 
-          "Foi calculado um tamanho de amostra de <b>", n , "</b> sujeitos, sendo <b>",
-          if (input$balanceamento == 1) {
-            paste0(
-              n1, "</b> em cada grupo, "
-            )
-          } else {
-            paste0(
-              n1, "</b> no <i>", nome_grupo_tratamento(), "</i> e <b>", n2, "</b> no <i>", nome_grupo_controle(), "</i>, "
-            )
-          },
+            "Foi calculado um tamanho de amostra de <b>", n , "</b> sujeitos, sendo <b>",
+            if (input$balanceamento == 1) {
+              paste0(
+                n1, "</b> em cada grupo, "
+              )
+            } else {
+              paste0(
+                n1, "</b> no <i>", nome_grupo_tratamento(), "</i> e <b>", n2, "</b> no <i>", nome_grupo_controle(), "</i>, "
+              )
+            },
 
-          "para estimar a razão de chances de desenvolver <i>",
-          nome_desfecho(), "</i> entre os grupos <i>",
-          nome_grupo_controle(), "</i> e <i>", nome_grupo_tratamento(),
-          "</i>, ",
-          "com amplitude desejada para o intervalo de confiança de <b>", input$amplitude, "</b> ",
+            "para estimar a razão de chances de desenvolver <i>",
+            nome_desfecho(), "</i> entre os grupos <i>",
+            nome_grupo_controle(), "</i> e <i>", nome_grupo_tratamento(),
+            "</i>, ",
+            "com amplitude desejada para o intervalo de confiança de <b>", input$amplitude, "</b> ",
 
-          if (input$balanceamento == 1) {
-            paste0("(com o acréscimo de <b>", input$perc_perdas, "%</b> para possíveis perdas e recusas este número deve ser <b>", nperdas1 + nperdas2, "</b>). ")
-          } else {
-            paste0("(com o acréscimo de <b>", input$perc_perdas, "%</b> para possíveis perdas e recusas este número deve ser ", nperdas1, " <i>", nome_grupo_tratamento(), "</i> e ", nperdas2, " <i>", nome_grupo_controle(), "</i>). ")
-          },
+            if (input$balanceamento == 1) {
+              paste0("(com o acréscimo de <b>", input$perc_perdas, "%</b> para possíveis perdas e recusas este número deve ser <b>", nperdas1 + nperdas2, "</b>). ")
+            } else {
+              paste0("(com o acréscimo de <b>", input$perc_perdas, "%</b> para possíveis perdas e recusas este número deve ser ", nperdas1, " <i>", nome_grupo_tratamento(), "</i> e ", nperdas2, " <i>", nome_grupo_controle(), "</i>). ")
+            },
 
-          "O cálculo (utilizando o método ", metodo, ") ",
-          "considerou nível de confiança de <b>", input$confianca, "%</b>, ",
-          text_just,
+            "O cálculo (utilizando o método ", metodo, ") ",
+            "considerou nível de confiança de <b>", input$confianca, "%</b>, ",
+            text_just,
+            .txt_citacao_pss
+          ),
 
-          .txt_citacao_pss,
           .txt_referencia_tap,
           print_r_code(code)
         )
@@ -876,19 +918,19 @@ mod_regressao_logistica_server <- function(id, tipo = "tamanho_amostral", txt_aj
 
           if (input$tipo_variavel == 1) {
             HTML(
-              paste0("<b>", translation_pss("Defina a sequência da razão de chances", linguagem()), ":</b>")
+              paste0("<b>", translation_pss("Defina a sequência da razão de chances", linguagem()), "</b>")
             )
           } else if (input$estatistica_tratamento == 'percent') {
             HTML(
-              paste0("<b>", translation_pss("Defina a sequência de valores (%) para o grupo", linguagem()) , nome_grupo_tratamento(), ":</b>")
+              paste0("<b>", translation_pss("Defina a sequência de valores (%) para o grupo", linguagem()) , nome_grupo_tratamento(), "</b>")
             )
           } else if (input$estatistica_tratamento == 'ratio') {
             HTML(
-              paste0("<b>", translation_pss("Defina a sequência do risco relativo", linguagem()),":</b>")
+              paste0("<b>", translation_pss("Defina a sequência do risco relativo", linguagem()),"</b>")
             )
           } else {
             HTML(
-              paste0("<b>", translation_pss("Defina a sequência da razão de chances", linguagem()), ":</b>")
+              paste0("<b>", translation_pss("Defina a sequência da razão de chances", linguagem()), "</b>")
             )
           },
 
@@ -901,8 +943,8 @@ mod_regressao_logistica_server <- function(id, tipo = "tamanho_amostral", txt_aj
               numericInput(ns("to"), translation_pss("Máximo", linguagem()), value = ratio_end, step = .1, min = 0, max = ratio_max)
           ),
           div(style="display: inline-block;vertical-align:top; width: 80px;",
-              numericInput(ns("by"), translation_pss("Intervalo", linguagem()), value = ratio_by, min = 0, step = .1) %>%
-                .help_buttom(body = translation_pss("Essa sequência será utilizada para compor o eixo x do gráfico. A sequência irá do valor <b>Mínimo</b> até o valor <b>Máximo</b> em intervalos definidos no <b>Intervalo</b>.", linguagem()),
+              numericInput(ns("by"), translation_pss("Intervalo", linguagem()), value = ratio_by, min = 0, step = .1) |>
+                .help_buttom(linguagem = linguagem(), body = translation_pss("Essa sequência será utilizada para compor o eixo x do gráfico. A sequência irá do valor <b>Mínimo</b> até o valor <b>Máximo</b> em intervalos definidos no <b>Intervalo</b>.", linguagem()),
                              title = "Sequência")
           ),
 
@@ -910,19 +952,19 @@ mod_regressao_logistica_server <- function(id, tipo = "tamanho_amostral", txt_aj
           fluidRow(
             column(6,
                    textInput(inputId = ns("poder_cenarios"),
-                             label   = translation_pss("Digite valores de poder (%) para fazer o gráfico:", linguagem()),
+                             label   = translation_pss("Digite valores de poder (%) para fazer o gráfico", linguagem()),
                              value   = "80, 90, 95",
-                             width   = "400px") %>%
-                     .help_buttom(body = ajuda_cenarios_multiplos_valores())
+                             width   = "400px") |>
+                     .help_buttom(linguagem = linguagem(), body = ajuda_cenarios_multiplos_valores())
             )
           ),
 
-          plotly::plotlyOutput(ns("grafico_cenarios"), width = "80%") %>%
+          plotly::plotlyOutput(ns("grafico_cenarios"), width = "80%") |>
             shinycssloaders::withSpinner(type = 5),
 
           br(), br(),
           downloadButton(ns("download_tabela_cenarios"), translation_pss("Download tabela", linguagem())),
-          DT::dataTableOutput(ns("tabela_cenarios"), width = "100%") %>%
+          DT::dataTableOutput(ns("tabela_cenarios"), width = "100%") |>
             shinycssloaders::withSpinner(type = 5)
 
         ))
@@ -981,12 +1023,12 @@ mod_regressao_logistica_server <- function(id, tipo = "tamanho_amostral", txt_aj
                                `Nível de significância (%)` = input$alpha,
                                `Poder (%)`   = poder,
                                Balanceamento = input$balanceamento,
-                               stringsAsFactors = FALSE) %>%
+                               stringsAsFactors = FALSE) |>
           dplyr::filter(`% Tratamento` != `% Controle`)
 
         if (input$tipo_variavel == 0) {
 
-          simul_n <- simul_n %>%
+          simul_n <- simul_n |>
             mutate(
               probs = Balanceamento/(1 + Balanceamento),
 
@@ -1001,13 +1043,13 @@ mod_regressao_logistica_server <- function(id, tipo = "tamanho_amostral", txt_aj
               `n Tratamento` = ceiling(ntemp*(1 - probs)),
               `n Controle`   = ceiling(ntemp*probs),
               `n total` = `n Tratamento` + `n Controle`
-            ) %>%
+            ) |>
 
             dplyr::filter(!is.na(`n Tratamento`) & !is.na(`n Controle`))
 
         } else {
 
-          simul_n <- simul_n %>%
+          simul_n <- simul_n |>
             mutate(
               `n total` = powerMediation::SSizeLogisticCon(
                 p1 = input$logistic_rate_mean/100,
@@ -1022,7 +1064,7 @@ mod_regressao_logistica_server <- function(id, tipo = "tamanho_amostral", txt_aj
 
         }
 
-        simul_n %>%
+        simul_n |>
           left_join(df_inputs_prop, by = c("% Tratamento" = "prop_tratamento"))
 
 
@@ -1045,10 +1087,10 @@ mod_regressao_logistica_server <- function(id, tipo = "tamanho_amostral", txt_aj
           TRUE ~ translation_pss("Razão de chance", linguagem())
         )
 
-        g1 <- tab_p2_TH_cenarios() %>%
+        g1 <- tab_p2_TH_cenarios() |>
           mutate(
             `Poder (%)` = factor(`Poder (%)`)
-          ) %>%
+          ) |>
           ggplot(
             aes(x = !! sym(metrica),
                 y = `n total`,
@@ -1068,7 +1110,7 @@ mod_regressao_logistica_server <- function(id, tipo = "tamanho_amostral", txt_aj
 
 
         plotly::ggplotly(g1,
-                         tooltip = c("x", "colour", "y", translation_pss("Tratamento", linguagem()), translation_pss("Controle", linguagem()))) %>%
+                         tooltip = c("x", "colour", "y", translation_pss("Tratamento", linguagem()), translation_pss("Controle", linguagem()))) |>
           plotly::layout(annotations = list(x = 1, y = -0.1, text = translation_pss("* sem considerar perdas/ recusas.", linguagem()),
                                             showarrow = F, xref='paper', yref='paper',
                                             xanchor='right', yanchor='auto', xshift=0, yshift=0,
@@ -1098,7 +1140,7 @@ mod_regressao_logistica_server <- function(id, tipo = "tamanho_amostral", txt_aj
           TRUE ~ translation_pss("Razão de chance", linguagem())
         )
 
-        df_ <- tab_p2_TH_cenarios() %>%
+        df_ <- tab_p2_TH_cenarios() |>
           dplyr::select(
             c("% Controle",
               all_of(metrica),
@@ -1139,7 +1181,7 @@ mod_regressao_logistica_server <- function(id, tipo = "tamanho_amostral", txt_aj
         )
 
         if (input$tipo_variavel == 1) {
-          df_ %>%
+          df_ |>
             select(
               -c(
                 paste0("n ", nome_grupo_tratamento()),
@@ -1157,7 +1199,7 @@ mod_regressao_logistica_server <- function(id, tipo = "tamanho_amostral", txt_aj
 
       output$tabela_cenarios <- DT::renderDataTable({
 
-        return_table_tabela_cenarios() %>%
+        return_table_tabela_cenarios() |>
           DT::datatable(extensions = c('FixedColumns'),
                         rownames   = FALSE,
                         filter     = "none",
